import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:furman_now/src/utils/decode_polyline.dart';
import 'package:http/http.dart' as http;

import 'route.dart';

class TransportationSafeRideShuttleService {
  static const service =
      "https://furmansaferide.ridesystems.net/Services/JSONPRelay.svc";

  static const apiKey = "8882812681";

  static Future<http.Response> _serviceRequest(
      String endpoint, Map<String, dynamic>? queryParameters) async {
    Uri serviceUri = Uri.https(
        'furmansaferide.ridesystems.net',
        "/Services/JSONPRelay.svc/$endpoint",
        {...?queryParameters, 'apiKey': apiKey});
    return http.get(serviceUri);
  }

  static Future<TransportationRoute> fetchShuttleRoute() async {
    final response = await _serviceRequest(
        'GetRoutesForMapWithScheduleWithEncodedLine', {'isDispatch': 'false'});

    if (response.statusCode == 200) {
      // If the server did return a 200 OK response,
      // then parse the JSON.
      final json = jsonDecode(response.body);
      String encodedPolyline = json[0]["EncodedPolyline"];
      final points = decodeEncodedPolyline(encodedPolyline);
      var stops = (json[0]["Stops"] as List<dynamic>)
          .map((e) => Stop.fromLiveSafeJson(e))
          .toList();
      return TransportationRoute.fromPoints(
        points: points,
        color: Colors.red.shade300,
        stops: stops,
      );
    } else {
      // If the server did not return a 200 OK response,
      // then throw an exception.
      throw Exception('Failed to load SafeRide shuttle route.');
    }
  }
}
